@@ -11,6 +11,11 @@
 #include "nl80211.h"
 #include "ieee80211.h"
 
+#ifndef NL_CAPABILITY_VERSION_3_5_0
+#define nla_nest_start(msg, attrtype) \
+       nla_nest_start(msg, NLA_F_NESTED | (attrtype))
+#endif
+
 /* support for extack if compilation headers are too old */
 #ifndef NETLINK_EXT_ACK
 #define NETLINK_EXT_ACK 11
@@ -162,7 +167,7 @@ struct vendor_event {
 };
 
 #define VENDOR_EVENT(_id, _subcmd, _callback)				\
-	const struct vendor_event 					\
+	static const struct vendor_event 				\
 	vendor_event_ ## _id ## _ ## _subcmd = {			\
 		.vendor_id = _id,					\
 		.subcmd = _subcmd,					\
@@ -181,7 +186,7 @@ int handle_cmd(struct nl80211_state *state, enum id_input idby,
 struct print_event_args {
 	struct timeval ts; /* internal */
 	bool have_ts; /* must be set false */
-	bool frame, time, reltime;
+	bool frame, time, reltime, ctime;
 };
 
 __u32 listen_events(struct nl80211_state *state,
@@ -213,10 +218,13 @@ void print_ampdu_length(__u8 exponent);
 void print_ampdu_spacing(__u8 spacing);
 void print_ht_capability(__u16 cap);
 void print_vht_info(__u32 capa, const __u8 *mcs);
+void print_he_capability(const uint8_t *ie, int len);
 void print_he_info(struct nlattr *nl_iftype);
 
 char *channel_width_name(enum nl80211_chan_width width);
 const char *iftype_name(enum nl80211_iftype iftype);
+void print_iftype_list(const char *name, const char *pfx, struct nlattr *attr);
+void print_iftype_line(struct nlattr *attr);
 const char *command_name(enum nl80211_commands cmd);
 int ieee80211_channel_to_frequency(int chan, enum nl80211_band band);
 int ieee80211_frequency_to_channel(int freq);
@@ -249,13 +257,9 @@ int parse_random_mac_addr(struct nl_msg *msg, char *addrs);
 
 #define SCHED_SCAN_OPTIONS "[interval <in_msecs> | scan_plans [<interval_secs:iterations>*] <interval_secs>] "	\
 	"[delay <in_secs>] [freqs <freq>+] [matches [ssid <ssid>]+]] [active [ssid <ssid>]+|passive] "	\
-	"[randomise[=<addr>/<mask>]]"
+	"[randomise[=<addr>/<mask>]] [coloc] [flush]"
 int parse_sched_scan(struct nl_msg *msg, int *argc, char ***argv);
 
-DECLARE_SECTION(switch);
-DECLARE_SECTION(set);
-DECLARE_SECTION(get);
-
 void nan_bf(uint8_t idx, uint8_t *bf, uint16_t bf_len, const uint8_t *buf,
 	    size_t len);
 
@@ -264,4 +268,49 @@ char *hex2bin(const char *hex, char *buf);
 int set_bitrates(struct nl_msg *msg, int argc, char **argv,
 		 enum nl80211_attrs attr);
 
+
+/* sections */
+DECLARE_SECTION(ap);
+DECLARE_SECTION(auth);
+DECLARE_SECTION(cac);
+DECLARE_SECTION(channels);
+DECLARE_SECTION(coalesce);
+DECLARE_SECTION(commands);
+DECLARE_SECTION(connect);
+DECLARE_SECTION(cqm);
+DECLARE_SECTION(del);
+DECLARE_SECTION(dev);
+DECLARE_SECTION(disconnect);
+DECLARE_SECTION(event);
+DECLARE_SECTION(features);
+DECLARE_SECTION(ftm);
+DECLARE_SECTION(get);
+DECLARE_SECTION(help);
+DECLARE_SECTION(hwsim);
+DECLARE_SECTION(ibss);
+DECLARE_SECTION(info);
+DECLARE_SECTION(interface);
+DECLARE_SECTION(link);
+DECLARE_SECTION(list);
+DECLARE_SECTION(measurement);
+DECLARE_SECTION(mesh);
+DECLARE_SECTION(mesh_param);
+DECLARE_SECTION(mgmt);
+DECLARE_SECTION(mpath);
+DECLARE_SECTION(mpp);
+DECLARE_SECTION(nan);
+DECLARE_SECTION(ocb);
+DECLARE_SECTION(offchannel);
+DECLARE_SECTION(p2p);
+DECLARE_SECTION(phy);
+DECLARE_SECTION(reg);
+DECLARE_SECTION(roc);
+DECLARE_SECTION(scan);
+DECLARE_SECTION(set);
+DECLARE_SECTION(station);
+DECLARE_SECTION(survey);
+DECLARE_SECTION(switch);
+DECLARE_SECTION(vendor);
+DECLARE_SECTION(wowlan);
+
 #endif /* __IW_H */
